@@ -24,4 +24,10 @@ pub enum Error {
 
 	#[error("Transaction is not writable")]
 	TxNotWritable,
+
+	#[error("Key being inserted already exists")]
+	KeyAlreadyExists,
+
+	#[error("Value being checked was not correct")]
+	ValNotExpectedValue,
 }
